@@ -3,6 +3,18 @@ import Quartz
 
 
 class TestCAGradientLayer(TestCase):
+    def test_typed_enum(self):
+        self.assertIsTypedEnum(Quartz.CAGradientLayerType, str)
+
+    @min_os_level("10.6")
+    def testConstants10_6(self):
+        self.assertIsInstance(Quartz.kCAGradientLayerAxial, str)
+        self.assertIsInstance(Quartz.kCAGradientLayerRadial, str)
+
+    @min_os_level("10.14")
+    def testConstants10_14(self):
+        self.assertIsInstance(Quartz.kCAGradientLayerConic, str)
+
     @min_os_level("10.6")
     def testMethods10_6(self):
         self.assertResultHasType(
@@ -18,12 +30,3 @@ class TestCAGradientLayer(TestCase):
         self.assertArgHasType(
             Quartz.CAGradientLayer.setEndPoint_, 0, Quartz.CGPoint.__typestr__
         )
-
-    @min_os_level("10.6")
-    def testConstants10_6(self):
-        self.assertIsInstance(Quartz.kCAGradientLayerAxial, str)
-        self.assertIsInstance(Quartz.kCAGradientLayerRadial, str)
-
-    @min_os_level("10.14")
-    def testConstants10_14(self):
-        self.assertIsInstance(Quartz.kCAGradientLayerConic, str)
